Method: LibFST::Writer#emit_value_change

Defined in:
ext/libfst_rb.c

#emit_value_change(handle, data) ⇒ self

Use this method to emit a value change of a variable of known size (length different from 0 in #create_variable).

data.bytesize must match the length parameter of the variable creation.



2048
2049
2050
2051
2052
2053
2054
2055
# File 'ext/libfst_rb.c', line 2048

static VALUE libfst_writer_emit_value_change(VALUE self, VALUE handle, VALUE data)
{
	fstHandle hndl = rb_to_unsigned_int(handle);
	const char *dt = rb_string_value_ptr(&data);
	void *ctx = libfst_writer_from_rbobj(self);
	fstWriterEmitValueChange(ctx, hndl, dt);
	return self;
}